@@ -1,11 +1,8 @@
-from __future__ import absolute_import, division, print_function
-
 import numpy as np
 import pandas as pd
 from toolz import partial
 
 from ..utils import derived_from
-from .utils import PANDAS_VERSION
 
 
 def maybe_wrap_pandas(obj, x):
@@ -156,11 +153,6 @@ class StringAccessor(Accessor):
     def extractall(self, pat, flags=0):
         # TODO: metadata inference here won't be necessary for pandas >= 0.23.0
         meta = self._series._meta.str.extractall(pat, flags=flags)
-        if PANDAS_VERSION < "0.23.0":
-            index_name = self._series.index.name
-            meta.index = pd.MultiIndex(
-                levels=[[], []], labels=[[], []], names=[index_name, "match"]
-            )
         return self._series.map_partitions(
             str_extractall, pat, flags, meta=meta, token="str-extractall"
         )
